@@ -8,12 +8,11 @@ use WWW::Shopify;
 package WWW::Shopify::Model::Transaction;
 use parent 'WWW::Shopify::Model::Item';
 
-sub parent() { return "WWW::Shopify::Model::Order"; }
-sub mods() { return {
+sub parent { return "WWW::Shopify::Model::Order"; }
+my $fields; sub fields { return $fields; } 
+BEGIN { $fields = {
 	"amount" => new WWW::Shopify::Field::Money(),
-	"kind" => new WWW::Shopify::Field::String("(capture|no-capture)")};
-}
-sub stats() { return {
+	"kind" => new WWW::Shopify::Field::String("(capture|no-capture)"),
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"status" => new WWW::Shopify::Field::String("(success|failure)"),
 	"receipt" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Transaction::Receipt"),
@@ -22,8 +21,10 @@ sub stats() { return {
 	"gateway" => new WWW::Shopify::Field::String(),
 	"order_id" => new WWW::Shopify::Field::Relation::ReferenceOne('WWW::Shopify::Model::Order')};
 }
-sub minimal() { return ["path", "target"]; }
+sub creation_minimal { return qw(path target); }
+sub creation_filled { return qw(id created_at); }
+sub update_fields { return qw(amount kind); }
 
-eval(WWW::Shopify::Model::Item::generate_accessors(__PACKAGE__)); die $@ if $@;
+eval(__PACKAGE__->generate_accessors); die $@ if $@;
 
 1
